@@ -733,7 +733,8 @@ class SoftLinx:
             os.path.basename(filename), os.path.splitext(filename)[0] + ".ahk"
         )
         # *Add AutoHotKey filename to manifest list
-        self.addToManifest(os.path.splitext(filename)[0] + ".ahk")
+        #self.addToManifest(str(os.path.basename(filename)).replace(".slvp", ".ahk"))
+        self.addToManifest(os.path.splitext(os.path.basename(filename))[0] + ".ahk")
         # *Generate Manifest File
         self.generateManifest()   
         #)
